@@ -1,18 +1,17 @@
 # ---------------------------------------------------------------------------
 # tests/examples/test_mocking_objects_returning_mocked_objects.py
 #
-# Copyright (C) 2018 - 2020 Maciej Wiatrzyk
+# Copyright (C) 2019 - 2020 Maciej Wiatrzyk <maciej.wiatrzyk@gmail.com>
 #
 # This file is part of Mockify library and is released under the terms of the
 # MIT license: http://opensource.org/licenses/mit-license.php.
 #
 # See LICENSE for details.
 # ---------------------------------------------------------------------------
-import pytest
 
-from mockify import satisfied
-from mockify.mock import MockFactory
 from mockify.actions import Return
+from mockify.core import satisfied
+from mockify.mock import MockFactory
 
 
 class ItemRepositoryFacade:
@@ -36,4 +35,5 @@ class TestItemRepositoryFacade:
         response.json.expect_call().will_once(Return(expected_result))
 
         with satisfied(factory):
-            assert ItemRepositoryFacade(connection).get_items() == expected_result
+            assert ItemRepositoryFacade(connection
+                                        ).get_items() == expected_result
